# Phrase Hunter

This is a simple game for guessing the letters of a phrase, similar to hangman.

Install it with

`$ pip install phrase-hunter`

Run it with

`$ phrase-hunter`

## Source code

Majority of the code can be found in the classes in the included `phrasehunter`
package. This is my Unit 3 submission for my Treehouse Python Development TechDegree
so any and all feedback is welcome!
